Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/gitlab/experiment/rollout/feature.rb')
-rw-r--r--lib/gitlab/experiment/rollout/feature.rb7
1 files changed, 6 insertions, 1 deletions
diff --git a/lib/gitlab/experiment/rollout/feature.rb b/lib/gitlab/experiment/rollout/feature.rb
index bf31dfe08a0..4ff61aa3551 100644
--- a/lib/gitlab/experiment/rollout/feature.rb
+++ b/lib/gitlab/experiment/rollout/feature.rb
@@ -27,7 +27,8 @@ module Gitlab
#
# If the `Feature.enabled?` check is false, we return nil implicitly,
# which will assign the control. Otherwise we call super, which will
# assign a variant evenly, or based on our provided distribution rules.
def execute_assignment
super if ::Feature.enabled?(feature_flag_name, self, type: :experiment)
end
@@ -67,6 +68,10 @@ module Gitlab
def feature_flag_name
experiment.name.tr('/', '_')
end
+
+ def behavior_names
+ super - [:control]
+ end
end
end
end
@@ -27,7 +27,8 @@ module Gitlab
# If the `Feature.enabled?` check is false, we return nil implicitly,
# which will assign the control. Otherwise we call super, which will
- # assign a variant evenly, or based on our provided distribution rules.
+ # assign a variant based on our provided distribution rules.
+ # Otherwise we will assign a variant evenly across the behaviours without control.
def execute_assignment
super if ::Feature.enabled?(feature_flag_name, self, type: :experiment)